@@ -35,6 +35,7 @@
 #' @param phy.external see \code{\link{insilico}}
 #' @param phy.debias see \code{\link{insilico}}
 #' @param exclude.impossible.cause see \code{\link{insilico}}
+#' @param no.is.missing see \code{\link{insilico}}
 #' @param customization.dev Logical indicator for customized variables
 #' @param Probbase_by_symp.dev Not tested yet.
 #' @param probbase.dev The customized conditional probabilities of symptoms given causes, which could be in a different format than InterVA default, but it should consist of \code{nlevel.dev} levels rather than numerical values.
@@ -59,7 +60,7 @@
 #' @keywords InSilicoVA
 #' 
 #' @export insilico.fit
-insilico.fit <- function(data, isNumeric = FALSE, updateCondProb = TRUE, keepProbbase.level = TRUE,  CondProb = NULL, CondProbNum = NULL, datacheck = TRUE, datacheck.missing = TRUE, warning.write = FALSE, external.sep = TRUE, Nsim = 4000, thin = 10, burnin = 2000, auto.length = TRUE, conv.csmf = 0.02, jump.scale = 0.1, levels.prior = NULL, levels.strength = 1, trunc.min = 0.0001, trunc.max = 0.9999, subpop = NULL, java_option = "-Xmx1g", seed = 1, phy.code = NULL, phy.cat = NULL, phy.unknown = NULL, phy.external = NULL, phy.debias = NULL, exclude.impossible.cause = TRUE, customization.dev = FALSE, Probbase_by_symp.dev = FALSE, probbase.dev = NULL, table.dev = NULL, table.num.dev = NULL, gstable.dev = NULL, nlevel.dev = NULL, indiv.CI = NULL, ...){ 
+insilico.fit <- function(data, isNumeric = FALSE, updateCondProb = TRUE, keepProbbase.level = TRUE,  CondProb = NULL, CondProbNum = NULL, datacheck = TRUE, datacheck.missing = TRUE, warning.write = FALSE, external.sep = TRUE, Nsim = 4000, thin = 10, burnin = 2000, auto.length = TRUE, conv.csmf = 0.02, jump.scale = 0.1, levels.prior = NULL, levels.strength = 1, trunc.min = 0.0001, trunc.max = 0.9999, subpop = NULL, java_option = "-Xmx1g", seed = 1, phy.code = NULL, phy.cat = NULL, phy.unknown = NULL, phy.external = NULL, phy.debias = NULL, exclude.impossible.cause = TRUE, no.is.missing = FALSE, customization.dev = FALSE, Probbase_by_symp.dev = FALSE, probbase.dev = NULL, table.dev = NULL, table.num.dev = NULL, gstable.dev = NULL, nlevel.dev = NULL, indiv.CI = NULL, ...){ 
   # handling changes throughout time
   args <- as.list(match.call())
   if(!is.null(args$length.sim)){
@@ -261,12 +262,24 @@ removeBad <- function(data, is.numeric, subpop){
 	if(is.null(subpop)) return(list(data = data[-err, ], subpop = NULL))
 }
 
+## Update: for the first 9 symptoms (age and gender) instead of imputing 0, we impute NA
+##         this can also be customized to set to more symptoms...
 datacheck.interVAJava <- function(data, obj, warning.write){
 		
 		# this has been updated to correspond to the 4.03 version probbase which contains minor changes from before.
 		data("probbase3", envir = environment())
 		probbase <- get("probbase3", envir  = environment())
 
+		
+		# THIS STEP CHECKS HOW 'STRUCTURED MISSING' ARE IMPLEMENTED, SEE VIGNETT FOR DETAILS.
+		# 1. if no symptoms should be checked to be missing...
+		# zero_to_missing_list <- 0
+		# 2. if only symptoms not asked due to demographics are set to missing...
+		# zero_to_missing_list <- 1:9
+		# 3. if all symptoms not asked are set to missing ---> DEFAULT 
+		# zero_to_missing_list <- 1 : (dim(data)[2] - 1)
+		zero_to_missing_list <- 1 : (dim(data)[2] - 1)
+
 		# get text matrix
 		dontask0 <- probbase[-1, 4:11]
 		askif0 <- probbase[-1, 12]
@@ -289,13 +302,14 @@ datacheck.interVAJava <- function(data, obj, warning.write){
 		dontask.j <- .jarray(dontask, dispatch = TRUE)
 		askif.j <- .jarray(askif, dispatch = TRUE)
 		data.j <- .jarray(data.num, dispatch = TRUE)
+		zero_to_missing_list.j = .jarray(as.integer(zero_to_missing_list), dispatch = TRUE)
 
 		if(!warning.write){
-			checked  <- .jcall(obj, "[[D", "Datacheck", dontask.j, askif.j, data.j)
+			checked  <- .jcall(obj, "[[D", "Datacheck", dontask.j, askif.j, zero_to_missing_list.j, data.j)
 		}else{
 			id.j <- .jarray(as.character(data[, 1]), dispatch = TRUE)
 			symps.j <- .jarray(colnames(data)[-1], dispatch = TRUE)
-			checked  <- .jcall(obj, "[[D", "Datacheck", dontask.j, askif.j, data.j, id.j, symps.j, "warning_insilico.txt")
+			checked  <- .jcall(obj, "[[D", "Datacheck", dontask.j, askif.j, zero_to_missing_list.j, data.j, id.j, symps.j, "warning_insilico.txt")
 		}
 
 		return(do.call(rbind, lapply(checked, .jevalArray)))
@@ -325,7 +339,7 @@ removeExt <- function(data, prob.orig, is.Numeric, subpop, subpop_order_list, ex
 		pos <- "Y"
 	}
 	ext.where <- which(apply(extData, 1, function(x){
-									length(which(x == pos)) }) > 0)
+									length(which(x == pos)) }) > 0)	
 	extData <- as.matrix(extData[ext.where, ])
 	ext.id <- data[ext.where, 1]
 	ext.sub <- subpop[ext.where]
@@ -367,11 +381,13 @@ removeExt <- function(data, prob.orig, is.Numeric, subpop, subpop_order_list, ex
 	ext.cod[which(extData[,12] == pos)] <- extCauses[9]
 
 	# delete death confirmed external
-	data <- data[-ext.where, ]
-
-	data <- data[, -(extSymps + 1)]
+	if(length(ext.where) > 0){
+		data <- data[-ext.where, ]
+	}	
+	if(length(extSymps) > 0) data <- data[, -(extSymps + 1)]
 	# delete the causes from probbase
 	prob.orig <- prob.orig[ -(extSymps), -(extCauses)]
+
 	if(!is.null(subpop)){
 		ext.csmf <- vector("list", length(subpop_order_list))
 		for(i in 1:length(ext.csmf)){
@@ -391,8 +407,9 @@ removeExt <- function(data, prob.orig, is.Numeric, subpop, subpop_order_list, ex
 		}
 		ext.csmf <- ext.csmf/N.all		
 	}
+	if(length(ext.where) > 0) subpop <- subpop[-ext.where]
 	return(list(data = data, 
-				subpop = subpop[-ext.where],
+				subpop = subpop,
 				prob.orig = prob.orig, 
 				ext.sub  = ext.sub,
 				ext.id = ext.id, 
@@ -476,6 +493,9 @@ ParseResult <- function(N_sub.j, C.j, S.j, N_level.j, pool.j, fit){
 ##----------------------------------------------------------##
 ##       Helper functions all loaded                        ##
 ##----------------------------------------------------------##
+	if(no.is.missing){
+		data[data == ""] <- "."
+	}
 
 	if(is.null(java_option)) java_option = "-Xmx1g"
 	options( java.parameters = java_option )
@@ -637,6 +657,19 @@ ParseResult <- function(N_sub.j, C.j, S.j, N_level.j, pool.j, fit){
 		data[, j] <- toupper(data[, j])
 	}
   	##----------------------------------------------------------##
+
+
+  	if(datacheck){
+		cat("Performing data consistency check...\n")
+		checked <- datacheck.interVAJava(data, obj, warning.write)
+		cat("Data check finished.\n")
+		## update in data with missing, nothing is updated into missing, so only changing Y and N
+		for(i in 1:(dim(data)[2]-1)){
+			data[which(checked[, i] == 1), i+1] <- "Y"
+			data[which(checked[, i] == 0), i+1] <- ""
+			data[which(checked[, i] == -1), i+1] <- "."
+		}	
+  	}
   	## remove external causes
   	if(external.sep){
   		externals <- removeExt(data,prob.orig, isNumeric, subpop, subpop_order_list, external.causes, external.symps)
@@ -645,16 +678,6 @@ ParseResult <- function(N_sub.j, C.j, S.j, N_level.j, pool.j, fit){
   		prob.orig <- externals$prob.orig
   	}
 
-  	if(datacheck.missing && datacheck){
-		cat("Performing data consistency check...\n")
-		checked <- datacheck.interVAJava(data, obj, warning.write)
-		cat("Data check finished.\n")
-		## update in data with missing, nothing is updated into missing, so only changing Y and N
-		for(i in 1:(dim(data)[2]-1)){
-			data[which(checked[, i] == 1), i+1] <- "Y"
-			data[which(checked[, i] == -1), i+1] <- ""
-		}	
-  	}
 	##----------------------------------------------------------##
    	## check the missing list
    	## this step is after removing bad data and before data-checking
@@ -682,14 +705,7 @@ ParseResult <- function(N_sub.j, C.j, S.j, N_level.j, pool.j, fit){
    	## check interVA rules, ignoring missing at this step,
    	## since missing could be rewritten 
    	if((!datacheck.missing) && datacheck){
-		cat("Performing data consistency check...\n")
-		checked <- datacheck.interVAJava(data, obj, warning.write)
-		cat("Data check finished.\n")
-		## update in data with missing, nothing is updated into missing, so only changing Y and N
-		for(i in 1:(dim(data)[2]-1)){
-			data[which(checked[, i] == 1), i+1] <- "Y"
-			data[which(checked[, i] == 0), i+1] <- ""
-		}	
+		cat("check missing after removing symptoms are disabled...\n")
 	}
 
 
@@ -1207,7 +1223,9 @@ ParseResult <- function(N_sub.j, C.j, S.j, N_level.j, pool.j, fit){
     						  p.indiv[, (ext1:C.j)])
     	
     	p.indiv.ext <- matrix(0, nrow = length(externals$ext.id), ncol = C.j + length(external.causes) )
-    	for(i in 1:length(externals$ext.id)){p.indiv.ext[i, externals$ext.cod[i]] <- 1}
+    	if(length(externals$ext.id) > 0){
+	    	for(i in 1:length(externals$ext.id)){p.indiv.ext[i, externals$ext.cod[i]] <- 1}    		
+    	}
     	p.indiv <- rbind(p.indiv, p.indiv.ext) 
     	id <- c(id, externals$ext.id)
     	subpop <- c(subpop, externals$ext.sub)
